<?php

namespace Focus\Generalmanager\Policies;

use Litepie\User\Contracts\UserPolicy;
use Focus\Generalmanager\Models\Generalmanager;

class GeneralmanagerPolicy
{

    /**
     * Determine if the given user can view the generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function view(UserPolicy $user, Generalmanager $generalmanager)
    {
        if ($user->canDo('generalmanager.generalmanager.view') && $user->isAdmin()) {
            return true;
        }

        return $generalmanager->user_id == user_id() && $generalmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('generalmanager.generalmanager.create');
    }

    /**
     * Determine if the given user can update the given generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function update(UserPolicy $user, Generalmanager $generalmanager)
    {
        if ($user->canDo('generalmanager.generalmanager.edit') && $user->isAdmin()) {
            return true;
        }

        return $generalmanager->user_id == user_id() && $generalmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Generalmanager $generalmanager)
    {
        return $generalmanager->user_id == user_id() && $generalmanager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Generalmanager $generalmanager)
    {
        if ($user->canDo('generalmanager.generalmanager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given generalmanager.
     *
     * @param UserPolicy $user
     * @param Generalmanager $generalmanager
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Generalmanager $generalmanager)
    {
        if ($user->canDo('generalmanager.generalmanager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
