<?php

namespace Focus\Generalmanager\Providers;

use Illuminate\Support\ServiceProvider;

class GeneralmanagerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'generalmanager');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'generalmanager');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('focus.generalmanager', function ($app) {
            return $this->app->make('Focus\Generalmanager\Generalmanager');
        });

                // Bind Generalmanager to repository
        $this->app->bind(
            'Focus\Generalmanager\Interfaces\GeneralmanagerRepositoryInterface',
            \Focus\Generalmanager\Repositories\Eloquent\GeneralmanagerRepository::class
        );

        $this->app->register(\Focus\Generalmanager\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Focus\Generalmanager\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['focus.generalmanager'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('focus/generalmanager.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/generalmanager')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/generalmanager')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
